<<dd_version: 2>>
### Stata 16 additions to the `dyndoc` command

* The `docx` option allows turning markdown+dyndoc tags into Microsoft Word-compatible files.

* The `embedimage` option places graphics into the document itself instead of having them as linked files. The graphics must be `png`, `jpg`, `tif`, or `gif` files. Any other file types (such as `svg` or `pdf`) will still be linked.


### Using Stata's official `dyndoc` command.

A couple of things to note:

* If a `<<dd_do>>` block has any Stata input or output, it must be surrounded by `~~~~` code-block fences.

* Be careful not to have successive `~~~~` blocks, as they will generate extra vertical space.

* The Stata commands within a `<<dd_do>>` will show any leading whitespace in the web page, so they should be flush left

### Energy Usage in 1978 Automobiles

 This is a meant to be a very simple exposition about modeling energy usage using Stata's auto dataset. What makes the dataset special is that it is from the year 1978. Notable occurrences in 1978 were that Wayne Gretzky signed with the Indianapolis Racers of the World Hockey Association, and that the Boston Red Sox folded a 14-game lead to the Yankees. Eek. Oh, and homebrewing of beer was legalized in the U.S. To make things work more nicely, let's pretend that this is some sort of sample of measurements, so that when we talk about "average energy consumption", it will make some sense.

Let's open the **auto** dataset, and look at its structure.

~~~~
<<dd_do>>
sysuse auto, clear
describe
<</dd_do>>
~~~~

We could use a `codebook` command here to look at all the variables, but it will take up too much space. Let's do this instead:

~~~~
<<dd_do>>
codebook, compact
<</dd_do>>
~~~~

For those unfamiliar with the system of weights and measures used in the United Stated (and Liberia), the important conversions to remember are that

* 1 mile = 1605 meters = 1.605 km
* 1 pound = 453.6 grams = 0.4536 kg
* 1 gallon = 3.7854 liters or about 15/4 liters
* 1 inch = 2.54 cm
* Hence 1 cubic inch = 16.387064 cc or about 16 3/8 cc
* 1 foot = 12 inches = 30.48cm
* Hence 1 cubic foot = 28316.847 cc or about 28 1/3 liters

One other oddity in the so-called traditional (or Standard or English or Imperial) system, is that energy usage is measured in miles per gallon (mpg). This is not good for analysis, because it makes for a non-linear relationship between weight and energy. This can be seen in following graph:

<<dd_do: nocommands>>
* this block has its commands hidden by the nocommands attribute.
 twoway (scatter mpg weight), title(Non-linearity mpg on weight)
<</dd_do>>
<<dd_graph:saving(mpg_wt.png), height(400) replace>>

To make the analysis work better, we should make a variable measuring gallons use per 100 miles driven:

~~~~
<<dd_do>>
gen gp100m = 100/mpg, before(mpg)
label variable gp100m "Gallons per 100 miles"
<</dd_do>>
~~~~

One last conversion 1 gallon per 100 miles is about 75/32
(= <<dd_display: %6.3f 75/32>>) liters per 100 km.

Let's take a look at the means of various variables by whether the cars are from the US (_domestic_), or whether they are from outside the US (_foreign_). This was 1978, so country of manufacture mostly matched location of company. This is, of course, no longer the case.

~~~~
<<dd_do>>
tabstat gp100m weight length turn displacement gear_ratio, ///
  statistics( mean sd count ) by(foreign) format(%9.2fc)
<</dd_do>>
~~~~

This works, but it would be nice to have a table which makes it easier compare the means. We can do this simply by removing the extra statistics.

~~~~
<<dd_do>>
tabstat gp100m weight length turn displacement gear_ratio, ///
  statistics( mean ) by(foreign) format(%9.2fc)
<</dd_do>>
~~~~

Before modelling, we should take a look to see if there could be collinearities in the predictors.

<!-- graph matrix gp100m weight length turn displacement gear_ratio -->
<<dd_do: nocommands>>
graph matrix gp100m weight displacement gear_ratio
<</dd_do>>
<<dd_graph:saving(gmatrix.svg) replace>>

Finally, how about modelling? Let's first run a regression with many variables and then store the results

~~~~
<<dd_do>>
regress gp100m weight displacement gear_ratio foreign
<</dd_do>>
~~~~
<<dd_do: nocommands>>
estimates store e_wdgf
<</dd_do>>


We can see that, as expected, heavier cars take more energy to move. Perhaps unexpectedly, non-US cars use more gas at the same weight. It appears that we can throw out both `displacement` and `gear_ratio` as predictors and fit a simpler model.

~~~~
<<dd_do>>
regress gp100m weight foreign
<</dd_do>>
~~~~
<<dd_do: nocommands>>
estimates store e_wf
<</dd_do>>

We can put these coefficients in a table

~~~~
<<dd_do: nocommands>>
esttab e_wdgf e_wf
<</dd_do>>
~~~~

From the simple model, cars from 40 years ago used
<<dd_display: %5.3f _b[weight]*100>>
gallons per mile per extra 100 pounds, on average. Also, non-US cars use about <<dd_display: %5.3f _b[foreign]>>
more gallons per mile, on average, all other things being equal.
