*! version 1.0.0 September 26, 2019 @ 04:38:16
*! makes a putdocx document without the blocks from Stata 16
version 16.0
set more off 
capture log close putdocx16
log using putdocx16, name(putdocx16) replace

** need a code definition
local code font("Courier New",,"0000aa") // blue to look nice

capture putdocx clear  // in case last compile failed
** start accumulating the document
putdocx begin, footer(simplefoot)
** once started, put in the footer info
putdocx paragraph, tofooter(simplefoot)
putdocx table foot = (1,2), border(all, nil) tofooter(simplefoot)
putdocx table foot(1,1)=("1978 Auto Energy Report: Background")
putdocx table foot(1,1), halign(left)
putdocx table foot(1,2)=(""), pagenumber
putdocx table foot(1,2), halign(right)

putdocx paragraph, style(Title)
putdocx text ("Energy Usage in 1978 Automobiles")

putdocx paragraph, style(Heading1)
putdocx text ("Background")

putdocx textblock begin
This is a meant to be a very simple exposition about modeling energy usage using Stata's auto dataset.
 For those who are unfamiliar with the auto dataset, it is simply a list of makes and models and some of their automotive characteristics.
 What makes the dataset special is that it is from the year 1978.
 Notable occurrences in 1978 were that Wayne Gretzky signed with the Indianapolis Racers of the World Hockey Association, and that the Boston Red Sox folded a 14-game lead to the Yankees. Eek.
 Oh, and homebrewing of beer was legalized in the U.S.
 To make things work more nicely, let's pretend that this is some sort of sample of measurements, so that when we talk about "average energy consumption", it will make some sense.
putdocx textblock end

putdocx paragraph
putdocx text ("We'll open the ")
putdocx text ("auto"), bold
putdocx text (" dataset, and look at its structure behind the scenes.")
putdocx text (" The ")
putdocx text ("putdocx"), `code'
putdocx textblock append
 command cannot not show Stata code or output in general.
 It instead is made for putting tables and other output into a report, without showing any Stata code.
 So, we'll have to do some work, and then report just the results.
putdocx textblock end

*** none of this will either be seen as input or as output
sysuse auto, clear
describe
tabstat price mpg weight displacement, ///
  statistics( mean sd count ) columns(statistics) ///
  save
* we need to make a new matrix to be sure that putdocx gets the names right
matrix Stats = r(StatTotal)'

putdocx paragraph
putdocx text ("Here are some summary statistics about 1978 automobiles:")

putdocx table tabstat1 = matrix(Stats), rownames colnames

putdocx paragraph
putdocx text ("For those unfamiliar with the system of weights and measures used in the United States (and Liberia), the important conversions to remember are that")

putdocx paragraph, indent(left, 0.5cm)
putdocx text ("1 mile = 1605 meters = 1.605 km"), linebreak(1)
putdocx text ("1 pound = 454.6 grams = 0.4546 kg"), linebreak(1)
putdocx text ("1 gallon = 3.7854 liters or about 15/4 liters"), linebreak(1)
putdocx text ("1 inch = 2.54 cm"), linebreak(1)
putdocx text ("Hence 1 cubic inch = 16.387064 cc or about 16 3/8 cc"), linebreak(1)
putdocx text ("1 foot = 12 inches = 30.48cm"), linebreak(1)
putdocx text ("Hence 1 cubic foot = 28316.847 cc or about 28 1/3 liters"), linebreak(1)

putdocx textblock begin
One other oddity in the so-called traditional (or Standard or English or Imperial) system, is that energy usage is measured in miles per gallon (mpg).
 This is not good for analysis, because it makes for a non-linear relationship between weight and energy. This can be seen in following graph:
putdocx textblock end

twoway (scatter mpg weight), title(Non-linearity mpg on weight)
graph export mpg_wt.png, replace

putdocx paragraph, halign(center)
putdocx image mpg_wt.png, height(10cm)

putdocx paragraph
putdocx text ("To make the analysis work better, we will make a variable measuring gallons use per 100 miles driven.")

gen gp100m = 100/mpg, before(mpg)
label variable gp100m "Gallons per 100 miles"

putdocx text (" This requires one last conversion: 1 gallon per 100 miles is about 75/32 (= `:display %5.3f 75/32') liters per 100 km.")

putdocx paragraph
putdocx text ("Let's take a look at various variables by whether the cars are from the US (")
putdocx text ("domestic"), italic
putdocx text (") or whether they are from outside the US (")
putdocx text ("foreign"), italic
putdocx text (").")
putdocx text ("This was 1978, so country of manufacture mostly matched location of company. This is, of course, no longer the case.")

** getting this tabstat to work takes some work!
tabstat gp100m weight length turn displacement gear_ratio, ///
  statistics( mean sd count ) by(foreign) save
matrix Stats = r(Stat1)\r(Stat2)\r(StatTotal) 
putdocx table tabstat2 = matrix(r(Stat1)\r(Stat2)\r(StatTotal)), rownames colnames
putdocx table tabstat2(.,1), addcols(1, before)
putdocx table tabstat2(2,1)=(`"`r(name1)'"')
putdocx table tabstat2(5,1)=(`"`r(name2)'"')
putdocx table tabstat2(8,1)=("Overall")
putdocx table tabstat2(.,3/8), nformat(%9.2fc)
putdocx table tabstat2(4 7 10,3/8), nformat(%9.0g)
putdocx table tabstat2(2/10,3/8), halign(right)
putdocx paragraph
putdocx text ("Before modelling, we should take a look to see if there could be collinearities in the predictors.")

graph matrix gp100m weight displacement gear_ratio
graph export graph_mat.png, replace

putdocx paragraph, halign(center)
putdocx image graph_mat.png, height(10cm)


putdocx sectionbreak, footer(modelfoot)
putdocx paragraph, style(Heading1)
putdocx text ("Modeling")

putdocx paragraph, tofooter(modelfoot)
putdocx table mfoot = (1,2), border(all, nil) tofooter(modelfoot)
putdocx table mfoot(1,1)=("1978 Auto Energy Report: Modeling")
putdocx table mfoot(1,1), halign(left)
putdocx table mfoot(1,2)=(""), pagenumber
putdocx table mfoot(1,2), halign(right)


putdocx paragraph
putdocx text ("Finally, how about modelling? Let's first run a regression with many variables:")

regress gp100m weight displacement gear_ratio foreign
putdocx table regress1 = etable
estimates store e_wdgf

putdocx paragraph
putdocx text ("We can see that, as expected, heavier cars take more energy to move, an that, as not expected, non-US cars use more gas at the same weight.")
putdocx text (" It appears that we can throw out both ")
putdocx text ("displacement"), `code'
putdocx text (" and ")
putdocx text ("gear_ratio"), `code'
putdocx text (" as predictors and fit a simpler model.")

regress gp100m weight foreign
putdocx table regress1 = etable
estimates store e_wf

	
putdocx paragraph
putdocx text ("We can put these coefficients in a table using the community-contributed ")
putdocx text ("reg2docx"), `code'
putdocx text (".")

putdocx save "putdocx16", replace

reg2docx e_wdgf e_wf using twoetable.docx, replace

putdocx append putdocx twoetable, saving(putdocx, replace)

putdocx begin

putdocx paragraph

putdocx text ("From the simple model, cars from `= yofd(date(`"`c(current_date)'"',"DMY"))' years ago used ")
putdocx text ("`: display %5.3f _b[weight]*100'")
putdocx text (" gallons per mile per extra 100 pounds, on average.")
putdocx text (" Also, non-US cars use about ")
putdocx text ("`: display %5.3f _b[foreign]'")
putdocx text (" more gallons per mile, on average, all other things being equal.")

putdocx save "putdocx16", append
log close putdocx16
